@@ -1,14 +1,39 @@
 import json
 import sys
+import copy
 
+# This config contains variables whose values we never expect to change,
+# they are used in some experiments.
+EXPCONFIG = {
+    # Reset solver for each size of MUS
+    "resetSolverMUS": False,
+    # Reset solver for every call (VERY slow)
+    "resetSolverFull": False,
+    # Dump out SAT instances, for other MUS solvers
+    # WHen using this, set cores=0 and repeats=1
+    "dumpSAT": False,
+    # Change glucose's random seed at each solver reboot (requires chris' patched python-sat)
+    "changeSolverSeed": False,
+    # TO CHECK: Does this help?
+    "setPhases": False,
+    # Cache MUSes between steps
+    "useCache": True,
+    # Use same pool of solvers throughout
+    "reusePool": False,
+    # Make use of unsat cores when shrinking MUSes
+    "useUnsatCores": True,
+    # Use 'incremental' mode in solver
+    # Todo: Sometimes this makes the solver go super-slow
+    "solverIncremental": False,
+    # Limit search to searchLimitedBudget conflicts
+    "solveLimited": True,
+    "solveLimitedBudget": 10000,
+    # Which solver to use (g4 = glucose), z3 = Use Z3
+    "solver": "g4",
 
-# WOOO EVERY LOVES GLOBAL VARIABLES!!!
+}
 
-
-# let's put all our config into one variable because.. then we only have one global?
-
-
-CONFIG = {
+CONFIG_FAST = {
     # How many cores to use when running in parallel
     # Set to 1 (or 0) to disable parallelisation
     "cores": 8,
@@ -17,23 +42,7 @@ CONFIG = {
     "smallRepeats": 1,
     # How many times to try looking for each size of core
     "repeats": 2,
-    # Encode "at most one thing is true" as a single clause
-    "OneClauseAtMost": False,
-    # Limit search to searchLimitedBudget conflicts
-    "solveLimited": True,
-    "solveLimitedBudget": 10000,
-    # Dump out SAT instances, for other MUS solvers
-    # WHen using this, set cores=0 and repeats=1
-    "dumpSAT": False,
-    # TO CHECK: Does this help?
-    "setPhases": False,
-    # Cache MUSes between steps
-    "useCache": True,
-    # Which solver to use (g4 = glucose), z3 = Use Z3
-    "solver": "g4",
-    # Use 'incremental' mode in solver
-    # Todo: Sometimes this makes the solver go super-slow
-    "solverIncremental": False,
+
     # Exit when a MUS of required size has been found
     "earlyExit": True,
     # When "officially" looking for a mus of size k,
@@ -45,16 +54,6 @@ CONFIG = {
     "checkCloseFirst": False,
     # Smallest size of MUS to look for
     "baseSizeMUS": 4,
-    # Make use of unsat cores when shrinking MUSes
-    "useUnsatCores": True,
-    # Reset solver for each size of MUS
-    "resetSolverMUS": False,
-    # Reset solver for every call (VERY slow)
-    "resetSolverFull": False,
-    # Use same pool of solvers throughout
-    "reusePool": False,
-    # Change glucose's random seed at each solver reboot (requires chris' patched python-sat)
-    "changeSolverSeed": False,
     # Alternative, safer, MUS-finding algorithm
     "gallopingMUSes": False,
     # Start by chopping big bits off MUSes, to encourage variety
@@ -66,14 +65,24 @@ CONFIG = {
     "minPrecheckStepsMUS": False,
 }
 
+CONFIG_MORE_MUS = copy.deepcopy(CONFIG_FAST)
+
+CONFIG_MORE_MUS["earlyExit"] = False
+CONFIG_MORE_MUS["cascadeMult"] = 4
+CONFIG_MORE_MUS["baseSizeMUS"] = 6
+CONFIG_MORE_MUS["repeats"] = 4
+
+def getDefaultConfig():
+    global CONFIG_FAST
+    return copy.deepcopy(CONFIG_FAST)
 
 def LoadConfigFromDict(dict):
-    global CONFIG
+    global CONFIG_FAST
     for (k, v) in dict.items():
-        if k not in CONFIG:
+        if k not in CONFIG_FAST:
             print("Invalid CONFIG option: " + k)
             sys.exit(1)
-        CONFIG[k] = v
+        CONFIG_FAST[k] = v
 
 
 def LoadConfigFromFile(file):
